==> kmp-authentication-impl-0.0.7-sources.jar: commonMain/io/privy/auth/session/RawAuthSessionResponse.kt <==
package io.privy.auth.session

import kotlinx.serialization.SerialName
import kotlinx.serialization.Serializable

@Serializable
public data class RawAuthSessionResponse(
    val user: PrivyUserResponse,
    val token: String?,
    @SerialName("refresh_token") val refreshToken: String?,
    @SerialName("session_update_action") val sessionUpdateAction: String,
    @SerialName("identity_token") val identityToken: String?
)

@Serializable
public data class RefreshUserResponse(
    val user: PrivyUserResponse,
    @SerialName("identity_token") val identityToken: String?
)

@Serializable
public data class PrivyUserResponse(
    val id: String,
    @SerialName("linked_accounts") val linkedAccounts: List<LinkedAccountResponse>,
)

@Serializable
public sealed interface LinkedAccountResponse {
  @Serializable
  @SerialName("custom_auth")
  public data class CustomAuth(
      @SerialName("custom_user_id") val customUserId: String,
      @SerialName("first_verified_at") val firstVerifiedAt: Int?,
      @SerialName("latest_verified_at") val latestVerifiedAt: Int?
  ) : LinkedAccountResponse

  @Serializable
  @SerialName("wallet")
  public data class WalletAccount(
      val address: String,
      @SerialName("chain_id") val chainId: String?,
      @SerialName("chain_type") val chainType: String?,
      @SerialName("wallet_client_type") val walletClientType: String,
      @SerialName("connector_type") val connectorType: String?,
      @SerialName("recovery_method") val recoveryMethod: String?,
      @SerialName("wallet_index") val hdWalletIndex: Int?,
      @SerialName("first_verified_at") val firstVerifiedAt: Int?,
      @SerialName("latest_verified_at") val latestVerifiedAt: Int?,
  ) : LinkedAccountResponse {
    public fun isPrivyWallet(): Boolean {
      return walletClientType == "privy" && connectorType == "embedded"
    }
  }

  @Serializable
  @SerialName("phone")
  public data class PhoneNumberAccount(@SerialName("phoneNumber") val phoneNumber: String) :
      LinkedAccountResponse

  @Serializable
  @SerialName("email")
  public data class EmailAddressAccount(@SerialName("address") val emailAddress: String) :
      LinkedAccountResponse
      
  @Serializable
  @SerialName("google_oauth")
  public data class GoogleOAuthAccount(
      val subject: String,
      val email: String,
      val name: String?,
      @SerialName("first_verified_at") val firstVerifiedAt: Int?,
      @SerialName("latest_verified_at") val latestVerifiedAt: Int?
  ) : LinkedAccountResponse

  @Serializable
  @SerialName("twitter_oauth")
  public data class TwitterOAuthAccount(
      val subject: String,
      val username: String,
      val name: String?,
      val email: String?,
      @SerialName("profile_picture_url") val profilePictureUrl: String?,
      @SerialName("first_verified_at") val firstVerifiedAt: Int?,
      @SerialName("latest_verified_at") val latestVerifiedAt: Int?
  ) : LinkedAccountResponse

  @Serializable
  @SerialName("discord_oauth")
  public data class DiscordOAuthAccount(
      val subject: String,
      val username: String,
      val email: String?,
      @SerialName("first_verified_at") val firstVerifiedAt: Int?,
      @SerialName("latest_verified_at") val latestVerifiedAt: Int?
  ) : LinkedAccountResponse

  @Serializable
  @SerialName("unknown")
  public data class UnknownAccount(val type: String) : LinkedAccountResponse
}

==> kmp-authentication-impl-0.6.0-sources.jar: commonMain/io/privy/auth/session/RawAuthSessionResponse.kt <==
package io.privy.auth.session

import kotlinx.serialization.SerialName
import kotlinx.serialization.Serializable

@Serializable
public data class RawAuthSessionResponse(
    val user: PrivyUserResponse,
    val token: String?,
    @SerialName("refresh_token") val refreshToken: String?,
    @SerialName("session_update_action") val sessionUpdateAction: String,
    @SerialName("identity_token") val identityToken: String?
)

@Serializable
public data class RefreshUserResponse(
    val user: PrivyUserResponse,
    @SerialName("identity_token") val identityToken: String?
)

@Serializable
public data class PrivyUserResponse(
    val id: String,
    @SerialName("linked_accounts") val linkedAccounts: List<LinkedAccountResponse>,
)

@Serializable
public sealed interface LinkedAccountResponse {
  @Serializable
  @SerialName("custom_auth")
  public data class CustomAuth(
      @SerialName("custom_user_id") val customUserId: String,
      @SerialName("first_verified_at") val firstVerifiedAt: Int?,
      @SerialName("latest_verified_at") val latestVerifiedAt: Int?
  ) : LinkedAccountResponse

  @Serializable
  @SerialName("wallet")
  public data class WalletAccount(
      @SerialName("id") val id: String?,
      @SerialName("address") val address: String,
      @SerialName("chain_id") val chainId: String?,
      @SerialName("chain_type") val chainType: String?,
      @SerialName("wallet_client_type") val walletClientType: String,
      @SerialName("connector_type") val connectorType: String?,
      @SerialName("recovery_method") val recoveryMethod: String?,
      @SerialName("wallet_index") val hdWalletIndex: Int?,
      @SerialName("first_verified_at") val firstVerifiedAt: Int?,
      @SerialName("latest_verified_at") val latestVerifiedAt: Int?,
  ) : LinkedAccountResponse {
    public fun isPrivyWallet(): Boolean {
      return walletClientType == "privy" && connectorType == "embedded"
    }
  }

  @Serializable
  @SerialName("phone")
  public data class PhoneNumberAccount(@SerialName("phoneNumber") val phoneNumber: String) :
      LinkedAccountResponse

  @Serializable
  @SerialName("email")
  public data class EmailAddressAccount(@SerialName("address") val emailAddress: String) :
      LinkedAccountResponse
      
  @Serializable
  @SerialName("google_oauth")
  public data class GoogleOAuthAccount(
      val subject: String,
      val email: String,
      val name: String?,
      @SerialName("first_verified_at") val firstVerifiedAt: Int?,
      @SerialName("latest_verified_at") val latestVerifiedAt: Int?
  ) : LinkedAccountResponse

  @Serializable
  @SerialName("twitter_oauth")
  public data class TwitterOAuthAccount(
      val subject: String,
      val username: String,
      val name: String?,
      val email: String?,
      @SerialName("profile_picture_url") val profilePictureUrl: String?,
      @SerialName("first_verified_at") val firstVerifiedAt: Int?,
      @SerialName("latest_verified_at") val latestVerifiedAt: Int?
  ) : LinkedAccountResponse

  @Serializable
  @SerialName("discord_oauth")
  public data class DiscordOAuthAccount(
      val subject: String,
      val username: String,
      val email: String?,
      @SerialName("first_verified_at") val firstVerifiedAt: Int?,
      @SerialName("latest_verified_at") val latestVerifiedAt: Int?
  ) : LinkedAccountResponse

  @Serializable
  @SerialName("passkey")
  public data class PasskeyAccount(
      @SerialName("credential_id") val credentialId: String,
      @SerialName("authenticator_name") val authenticatorName: String?,
      @SerialName("created_with_browser") val createdWithBrowser: String?,
      @SerialName("created_with_os") val createdWithOs: String?,
      @SerialName("created_with_device") val createdWithDevice: String?,
      @SerialName("public_key") val publicKey: String?,
      @SerialName("enrolled_in_mfa") val enrolledInMfa: Boolean,
      @SerialName("verified_at") val verifiedAt: Long,
      @SerialName("first_verified_at") val firstVerifiedAt: Long?,
      @SerialName("latest_verified_at") val latestVerifiedAt: Long?
  ) : LinkedAccountResponse

  @Serializable
  @SerialName("unknown")
  public data class UnknownAccount(val type: String) : LinkedAccountResponse
}
